%define subrel 1
Name:           sudo
Version:        1.9.15p5
Release:        %mkrel 1
Epoch:          1
Summary:        Allows command execution as the superuser or another user for specified users
License:        GPLv2+
Group:          System/Base
URL:            https://www.sudo.ws/
Source0:        https://www.sudo.ws/sudo/dist/%{name}-%{version}%{?pre}.tar.gz
Source1:        https://www.sudo.ws/sudo/dist/%{name}-%{version}%{?pre}.tar.gz.sig
Source2:        sudo.pamd
Source3:        sudoers
Patch1:         sudo-1.6.7p5-strip.patch
Patch2:         sudo-1.9.7-envdebug.patch
Patch3:         sudo-1.9.16p2-deb-CVE-2025-32462.patch
Patch4:         sudo-1.9.16p2-deb-CVE-2025-32463.patch
BuildRequires:  pkgconfig(audit)
BuildRequires:  bison
BuildRequires:  groff-for-man
BuildRequires:  pkgconfig(libcap)
BuildRequires:  openldap-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
Requires(pre):  openldap
# for create_ghostfile in post
Requires(post): rpm-helper

%description
Sudo (su "do") allows a system administrator to give certain users (or groups
of users) the ability to run some (or all) commands as the superuser or another
user, while logging all commands and arguments. Sudo operates on a per-command
basis, it is not a replacement for the shell.

%package devel
Summary:        Development files for sudo plugins
Group:          Development/C
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description    devel
Development files for compiling sudo plugins.

%prep
%autosetup -p1 -n %{name}-%{version}%{?pre}

# fix attribs
find -name "Makefile.*" | xargs perl -pi -e "s|-m 0444|-m 0644|g"


%build
# handle newer autoconf
rm -f acsite.m4
mv aclocal.m4 acinclude.m4
autoreconf -fv --install

%serverbuild
export CFLAGS="%{optflags} -D_GNU_SOURCE"

%configure \
        --without-rpath \
        --with-logging=both \
        --with-logfac=authpriv \
        --with-logpath=%{_logdir}/sudo.log \
        --with-editor=/bin/vi \
	--enable-openssl \
	--disable-root-mailer \
        --enable-log-host \
        --with-pam \
        --with-pam-login \
        --with-env-editor \
        --with-noexec=no \
        --with-linux-audit \
        --with-ignore-dot \
        --with-tty-tickets \
        --with-ldap \
        --with-ldap-conf-file=%{_sysconfdir}/nslcd.conf \
        --with-ldap-secret-file=%{_sysconfdir}/nslcd.conf \
        --with-secure-path="/sbin:%{_sbindir}:/bin:%{_bindir}:/usr/local/bin:/usr/local/sbin" \
        --with-passprompt="[sudo] password for %p: " \
        --with-plugindir=%{_libdir}/sudo \
	--with-sendmail=/usr/sbin/sendmail

%make_build

%install
install -d %{buildroot}/usr
install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}%{_sysconfdir}/sudoers.d
install -d %{buildroot}%{_sysconfdir}/pam.d
install -d %{buildroot}%{_var}/db/sudo
install -d %{buildroot}%{_var}/db/sudo/lectured
install -d %{buildroot}%{_logdir}/sudo
install -d %{buildroot}%{_logdir}/sudo-io

%make_install install_uid=$UID install_gid=$(id -g) sudoers=uid=$UID sudoers_gid=$(id -g)

install -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/pam.d/sudo
install -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sudoers

# Installing logrotated file
cat <<END >%{buildroot}%{_sysconfdir}/logrotate.d/sudo
%{_logdir}/sudo.log {
    missingok
    monthly
    compress
}
END

cat > %{buildroot}%{_sysconfdir}/pam.d/sudo << EOF
#%PAM-1.0
auth            include         system-auth
account         include         system-auth
password        include         system-auth
session         optional        pam_keyinit.so revoke
session         required        pam_limits.so
EOF

cat > %{buildroot}%{_sysconfdir}/pam.d/sudo-i << EOF
#%PAM-1.0
auth            include         sudo
account         include         sudo
password        include         sudo
session         optional        pam_keyinit.so force revoke
session         required        pam_limits.so
EOF

# so that strip can touch it...
chmod 755 %{buildroot}%{_bindir}/*
chmod 755 %{buildroot}%{_sbindir}/*

# (tpg) create the missing log file
touch %{buildroot}%{_logdir}/sudo.log

# move the lib to a common place
mv %{buildroot}%{_libexecdir}/sudo/* %{buildroot}%{_libdir}/
rm -rf %{buildroot}%{_libexecdir}/sudo

# cleanup
rm -rf %{buildroot}%{_datadir}/examples samples
cp -rp examples samples
rm -f samples/Makefile*
# too big
rm -f %{buildroot}%{_docdir}/%{name}/ChangeLog

find %{buildroot} -type f -name "*.la" | xargs rm

%find_lang sudo
%find_lang sudoers

cat sudo.lang sudoers.lang > sudo_all.lang
rm sudo.lang sudoers.lang

%check
LC_ALL=C LANG=C LANGUAGE=C
%__make check

%post
/bin/chmod 0440 %{_sysconfdir}/sudoers || :
%create_ghostfile %{_logdir}/sudo.log root root 600

%files -f sudo_all.lang
%doc samples
%{_docdir}/%{name}/CONTRIBUTING.md
%{_docdir}/%{name}/CONTRIBUTORS.md
%{_docdir}/%{name}/LICENSE.md
%{_docdir}/%{name}/NEWS
%{_docdir}/%{name}/HISTORY.md
%{_docdir}/%{name}/SECURITY.md
%{_docdir}/%{name}/README.md
%{_docdir}/%{name}/README.LDAP.md
%{_docdir}/%{name}/TROUBLESHOOTING.md
%{_docdir}/%{name}/UPGRADE.md
%{_docdir}/%{name}/schema.ActiveDirectory
%{_docdir}/%{name}/schema.OpenLDAP
%{_docdir}/%{name}/schema.iPlanet
%{_docdir}/%{name}/schema.olcSudo
%{_docdir}/%{name}/examples/*.conf
%{_docdir}/%{name}/examples/sudoers
%attr(0440,root,root) %config(noreplace) %{_sysconfdir}/sudoers
%attr(0440,root,root) %config(noreplace) %{_sysconfdir}/sudoers.dist
%attr(0440,root,root) %config(noreplace) %{_sysconfdir}/sudo.conf
%attr(0440,root,root) %config(noreplace) %{_sysconfdir}/sudo_logsrvd.conf
%attr(0750,root,root) %dir %{_sysconfdir}/sudoers.d/
%config(noreplace) %{_sysconfdir}/logrotate.d/sudo
%config(noreplace) %{_sysconfdir}/pam.d/sudo
%config(noreplace) %{_sysconfdir}/pam.d/sudo-i
%attr(0755,root,root) %{_bindir}/cvtsudoers
%attr(0755,root,root) %{_sbindir}/sudo_logsrvd
%attr(0755,root,root) %{_sbindir}/sudo_sendlog
%attr(4111,root,root) %{_bindir}/sudo
%{_bindir}/sudoedit
%attr(0111,root,root) %{_bindir}/sudoreplay
%attr(0755,root,root) %{_sbindir}/visudo
%ghost %{_logdir}/sudo.log
%{_mandir}/*/*
%attr(0700,root,root) %dir %{_var}/db/sudo
%attr(0700,root,root) %dir %{_var}/db/sudo/lectured
%attr(0750,root,root) %dir %{_logdir}/sudo-io
%attr(0755,root,root) %{_libdir}/sudo/group_file.so
%attr(0755,root,root) %{_libdir}/sudo/sudoers.so
%attr(0755,root,root) %{_libdir}/sudo/system_group.so
%attr(0755,root,root) %{_libdir}/sudo/audit_json.so
%{_libdir}/libsudo_util.so.0
%attr(0755,root,root) %{_libdir}/libsudo_util.so.*.*
%attr(0755,root,root) %{_libdir}/sudo_intercept.so
%{_tmpfilesdir}/sudo.conf

%files devel
%doc plugins/{group_file,sample}
%{_includedir}/sudo_plugin.h
%{_libdir}/libsudo_util.so


%changelog
* Thu Jul 24 2025 danf <danf> 1:1.9.15p5-1.1.mga9
+ Revision: 2258693
- Fix for CVE-2025-32462 and CVE-2025-32463
+ ns80 <ns80>
- new version 1.9.15p5 for CVE-2023-42465 (mga#32790)

* Fri Apr 07 2023 ns80 <ns80> 1:1.9.13p2-2.mga9
+ Revision: 1951640
- add an upstream patch for a regression introduced by the fix for CVE-2023-2848[67]

* Thu Mar 02 2023 luigiwalser <luigiwalser> 1:1.9.13p2-1.mga9
+ Revision: 1946202
- 1.9.13p2
+ wally <wally>
- update url (mga#31439)
- update summary and description (mga#31440)

* Fri Jan 20 2023 luigiwalser <luigiwalser> 1:1.9.12p2-1.mga9
+ Revision: 1934517
- 1.9.12p2

* Mon Nov 07 2022 luigiwalser <luigiwalser> 1:1.9.12p1-1.mga9
+ Revision: 1904534
- 1.9.12p1

* Fri Oct 21 2022 luigiwalser <luigiwalser> 1:1.9.11p3-1.mga9
+ Revision: 1898298
- 1.9.11p3

* Fri Apr 22 2022 luigiwalser <luigiwalser> 1:1.9.10-1.mga9
+ Revision: 1852726
- 1.9.10

* Wed Mar 30 2022 umeabot <umeabot> 1:1.9.7p2-3.mga9
+ Revision: 1833607
- Mageia 9 Mass Rebuild

* Fri Oct 01 2021 tmb <tmb> 1:1.9.7p2-2.mga9
+ Revision: 1747306
- rebuild for openssl 3.0.0

* Sun Aug 08 2021 luigiwalser <luigiwalser> 1:1.9.7p2-1.mga9
+ Revision: 1740300
- 1.9.7p2

* Sat May 15 2021 luigiwalser <luigiwalser> 1:1.9.7-1.mga9
+ Revision: 1723904
- 1.9.7
- rediff patches

* Sun Apr 04 2021 joequant <joequant> 1:1.9.6-1.mga9
+ Revision: 1713145
- update to 1.9.6

* Sat Jan 30 2021 tmb <tmb> 1:1.9.5p2-2.mga8
+ Revision: 1674047
- Fix NO_ROOT_MAILER, broken by the eventlog refactor in sudo 1.9.4.

* Tue Jan 26 2021 luigiwalser <luigiwalser> 1:1.9.5p2-1.mga8
+ Revision: 1673632
- 1.9.5p2

* Wed Jan 20 2021 luigiwalser <luigiwalser> 1:1.9.5p1-1.mga8
+ Revision: 1672620
- 1.9.5p1

* Mon Jan 11 2021 luigiwalser <luigiwalser> 1:1.9.5-1.mga8
+ Revision: 1671208
- 1.9.5

* Wed Dec 30 2020 luigiwalser <luigiwalser> 1:1.9.4p2-1.mga8
+ Revision: 1665931
- 1.9.4p2

* Wed Dec 02 2020 luigiwalser <luigiwalser> 1:1.9.4-1.mga8
+ Revision: 1651791
- set sendmail path in configure
- 1.9.4

* Tue Nov 03 2020 joequant <joequant> 1:1.9.3p1-1.mga8
+ Revision: 1641901
- update to 1.9.3p1

* Tue Sep 22 2020 luigiwalser <luigiwalser> 1:1.9.2-1.mga8
+ Revision: 1629466
- 1.9.2

* Sat May 23 2020 neoclust <neoclust> 1:1.9.0-1.mga8
+ Revision: 1587092
- New stable version 1.9.0

* Wed Apr 01 2020 luigiwalser <luigiwalser> 1:1.8.31p1-1.mga8
+ Revision: 1562830
- 1.8.31p1

* Thu Feb 20 2020 umeabot <umeabot> 1:1.8.31-2.mga8
+ Revision: 1545967
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 luigiwalser <luigiwalser> 1:1.8.31-1.mga8
+ Revision: 1485681
- 1.8.31
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Dec 29 2019 joequant <joequant> 1:1.8.29-1.mga8
+ Revision: 1474719
- upgrade to 1.8.29

* Tue Oct 15 2019 ns80 <ns80> 1:1.8.28-1.mga8
+ Revision: 1453531
- new version 1.8.28 for CVE-2019-14287 (mga#25568)

* Mon Jan 14 2019 luigiwalser <luigiwalser> 1:1.8.27-1.mga7
+ Revision: 1356300
- 1.8.27

* Fri Dec 28 2018 luigiwalser <luigiwalser> 1:1.8.26-1.mga7
+ Revision: 1345690
- 1.8.26

* Sun Sep 23 2018 umeabot <umeabot> 1:1.8.23-2.mga7
+ Revision: 1301224
- Mageia 7 Mass Rebuild

* Wed Jul 04 2018 luigiwalser <luigiwalser> 1:1.8.23-1.mga7
+ Revision: 1241506
- 1.8.23
- sudoers2ldif replaced by cvtsudoers

* Wed Apr 18 2018 kekepower <kekepower> 1:1.8.22-1.mga7
+ Revision: 1219835
- Update to version 1.8.22

* Tue Nov 21 2017 tmb <tmb> 1:1.8.21p2-2.mga7
+ Revision: 1178156
- Require rpm-helper for create_ghostfile call in post

* Sat Sep 09 2017 joequant <joequant> 1:1.8.21p2-1.mga7
+ Revision: 1152253
- update and rebuild

* Sat Jun 03 2017 luigiwalser <luigiwalser> 1:1.8.20p2-1.mga6
+ Revision: 1106327
- 1.8.20p2

* Wed May 31 2017 luigiwalser <luigiwalser> 1:1.8.20p1-1.mga6
+ Revision: 1105639
- 1.8.20p1 (fixes CVE-2017-1000367)

* Wed May 17 2017 luigiwalser <luigiwalser> 1:1.8.20-1.mga6
+ Revision: 1102283
- 1.8.20

* Wed Apr 05 2017 luigiwalser <luigiwalser> 1:1.8.19p2-1.mga6
+ Revision: 1095936
- 1.8.19p2

* Sun Jan 01 2017 luigiwalser <luigiwalser> 1:1.8.19p1-1.mga6
+ Revision: 1078932
- 1.8.19p1

* Fri Nov 11 2016 luigiwalser <luigiwalser> 1:1.8.18p1-1.mga6
+ Revision: 1066574
- 1.8.18p1 (fixes CVE-2016-7076)

* Tue Oct 04 2016 luigiwalser <luigiwalser> 1:1.8.18-1.mga6
+ Revision: 1058668
- 1.8.18
- add --disable-root-mailer configure option

* Wed Sep 14 2016 tv <tv> 1:1.8.17p1-2.mga6
+ Revision: 1052892
- sudoers: allow wheel group by default (mga#19342)

* Fri Jul 22 2016 luigiwalser <luigiwalser> 1:1.8.17p1-1.mga6
+ Revision: 1043128
- 1.8.17p1 (fixes CVE-2016-8239)

* Mon Jun 06 2016 luigiwalser <luigiwalser> 1:1.8.15-3.mga6
+ Revision: 1020458
- remove INPUTRC from env_keep due to possible info leak (rhbz#1339935)

* Wed Feb 17 2016 umeabot <umeabot> 1:1.8.15-2.mga6
+ Revision: 962964
- Mageia 6 Mass Rebuild
+ luigiwalser <luigiwalser>
- use nslcd.conf for ldap config instead of ldap.conf which no longer is used

* Mon Nov 09 2015 luigiwalser <luigiwalser> 1:1.8.15-1.mga6
+ Revision: 900136
- 1.8.15 (fixes CVE-2015-5602)
- remove upstreamed patches 3 and 4

* Wed Sep 23 2015 blino <blino> 1:1.8.12-3.mga6
+ Revision: 882306
- fix doc file list for rpm 4.13 (now errors out on unpackaged files in docdir)
+ luigiwalser <luigiwalser>
- disable visiblepw instead of enable requiretty in sudoers (mga#16590)

* Sat Feb 21 2015 luigiwalser <luigiwalser> 1:1.8.12-2.mga5
+ Revision: 816279
- add upstream patch to fix linking error with libsudo_util.so
- add upstream patch to fix handling when crypt() returns NULL

* Sat Feb 14 2015 oden <oden> 1:1.8.12-1.mga5
+ Revision: 814926
- bump release
- 1.8.12

* Wed Oct 15 2014 umeabot <umeabot> 1:1.8.10p3-4.mga5
+ Revision: 750013
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 luigiwalser <luigiwalser> 1:1.8.10p3-3.mga5
+ Revision: 737649
- add upstream patch to blacklist new-style bash function environment variables

* Tue Sep 16 2014 umeabot <umeabot> 1:1.8.10p3-2.mga5
+ Revision: 689578
- Mageia 5 Mass Rebuild

* Wed May 14 2014 luigiwalser <luigiwalser> 1:1.8.10p3-1.mga5
+ Revision: 622656
- 1.8.10p3

* Wed Mar 19 2014 luigiwalser <luigiwalser> 1:1.8.10p2-1.mga5
+ Revision: 605632
- 1.8.10p2

* Sat Mar 15 2014 luigiwalser <luigiwalser> 1:1.8.10p1-1.mga5
+ Revision: 603980
- 1.8.10p1

* Tue Mar 11 2014 luigiwalser <luigiwalser> 1:1.8.10-1.mga5
+ Revision: 601985
- 1.8.10

* Fri Feb 14 2014 luigiwalser <luigiwalser> 1:1.8.9p5-1.mga5
+ Revision: 591436
- 1.8.9p5

* Thu Nov 07 2013 tv <tv> 1:1.8.8-3.mga4
+ Revision: 549844
- disable patch4 (thus fixing iurt) (mga#11374)

* Mon Oct 21 2013 umeabot <umeabot> 1:1.8.8-2.mga4
+ Revision: 538827
- Mageia 4 Mass Rebuild

* Wed Oct 02 2013 luigiwalser <luigiwalser> 1:1.8.8-1.mga4
+ Revision: 490475
- 1.8.8

* Sun Jul 07 2013 luigiwalser <luigiwalser> 1:1.8.7-1.mga4
+ Revision: 451036
- 1.8.7
- remove upstreamed patch 3
- update files list

* Fri May 24 2013 luigiwalser <luigiwalser> 1:1.8.6p8-1.mga4
+ Revision: 426728
- 1.8.6p8

* Thu Feb 28 2013 luigiwalser <luigiwalser> 1:1.8.6p7-1.mga3
+ Revision: 400679
- 1.8.6p7

* Tue Feb 12 2013 luigiwalser <luigiwalser> 1:1.8.6p6-1.mga3
+ Revision: 397943
- 1.8.6p6

* Thu Jan 31 2013 luigiwalser <luigiwalser> 1:1.8.6p5-1.mga3
+ Revision: 393626
- 1.8.6p5

* Mon Jan 14 2013 umeabot <umeabot> 1:1.8.6p3-3.mga3
+ Revision: 383578
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 pterjan <pterjan> 1:1.8.6p3-2.mga3
+ Revision: 340151
- Place plugins in /usr/lib/sudo/ instead of libexecdir, they are .so to dlopen

* Sun Sep 23 2012 luigiwalser <luigiwalser> 1:1.8.6p3-1.mga3
+ Revision: 296897
- 1.8.6p3

* Sat Sep 15 2012 luigiwalser <luigiwalser> 1:1.8.6p1-1.mga3
+ Revision: 294256
- 1.8.6p1
- rediff patch 3
- remove upstreamed patch 5

* Sun Jul 29 2012 luigiwalser <luigiwalser> 1:1.8.5p1-1.mga3
+ Revision: 275808
- 1.8.5p1
- add pipelist and sssd-support patches from mdv
- other minor syncing with mdv package

* Thu May 17 2012 luigiwalser <luigiwalser> 1:1.8.3p2-2.mga3
+ Revision: 235868
- add patch for CVE-2012-2337 (improper netmask matching)

* Mon Jan 30 2012 boklm <boklm> 1:1.8.3p2-1.mga2
+ Revision: 203379
- Version 1.8.3.p2 (fixing format string vulnerability)

* Mon Oct 31 2011 fwang <fwang> 1:1.8.3p1-1.mga2
+ Revision: 160282
- new version 1.8.3p1

* Fri Oct 07 2011 shlomif <shlomif> 1:1.8.2-1.mga2
+ Revision: 152774
- New version of sudo - 1.8.2. Patch to SPEC contributed by barjac.
+ rtp <rtp>
- fix build with noexec disabled
- fix file list
+ tv <tv>
- drop patch 5 (merged upstream)
- new release

* Thu Mar 24 2011 pterjan <pterjan> 1:1.8.0-4.mga1
+ Revision: 76858
- Fix missing epoch in -devel dependency

* Wed Mar 23 2011 blino <blino> 1:1.8.0-3.mga1
+ Revision: 75835
- fix exit value of sudo -l command in sudoers module (from upstream)

* Mon Mar 21 2011 dmorgan <dmorgan> 1:1.8.0-2.mga1
+ Revision: 75107
- Add upstream patch for fix the use of the -n option ( Bug #475)

* Sat Mar 19 2011 boklm <boklm> 1:1.8.0-1.mga1
+ Revision: 74482
- update to version 1.8.0
- removed patches :
 * sudo-1.7.4p4-auditconn.patch: removed from fedora package
 * sudo-1.7.4p3-sudolist.patch: removed from fedora package
 * sudo-1.7.4p4-sudoi.patch: applied upstream
 * sudo-1.7.4p4-getgrouplist.patch: does not apply to new version, and
   needs small modifications. Fixing Red Hat bug #235915, but not applied
   upstream since 2007.
+ blino <blino>
- imported package sudo

